var Shaders = 
{
	OrganicPulse: 
	{
		'vertex':[ 
		   "uniform float amplitude;",
		   "attribute float displacement;", 
		   "varying vec3 vNormal;",
			"void main() {",
				"vNormal = normal;",
				"vec3 newPosition = position + vNormal * vec3(displacement * amplitude);",
				"gl_Position = projectionMatrix *",
							  "modelViewMatrix *",
							  "vec4(newPosition,1.0);",
		    "}"].join("\n"),
		
		'fragment':[
			"varying vec3 vNormal;",
			 "void main() {",
				 "vec3 light = vec3(0.5,0.2,1.0);",
				 "light = normalize(light);",
				 "float dProd = max(0.0, dot(vNormal, light));",
				 "gl_FragColor = vec4(dProd, dProd, dProd, 0.8);",
		   "}"].join("\n")
	}
}

var PlayerShaderContainer = function(object3D)
{
	this.material = CreateShaderMaterial(object3D);
	this.magnitude = 0.01;
	
	object3D.material = this.material;
	
	this.Update = function()
	{
		this.material.uniforms.amplitude.value = (Math.sin(this.magnitude)+2)/240;
		
		this.magnitude += 0.1;
	}
	
}


function CreateShaderMaterial(mesh)
{
	var numberOfVerts = mesh.geometry.vertices.length;

	var attributes = {
		displacement: {
			type: 'f',
			value: []
		}
	};
			
	var values = attributes.displacement.value;
	for(var v = 0; v < numberOfVerts; v++) {
		values.push(Math.random() * 30);
	}
	
	var uniforms = {
		amplitude: {
			type: 'f',
			value: 0.01,
		}
	};
	
	var shaderMaterial = new THREE.ShaderMaterial({
		attributes: 	attributes,
		uniforms:		uniforms,
		vertexShader:   Shaders.OrganicPulse.vertex,
		fragmentShader: Shaders.OrganicPulse.fragment
	});
	
	return shaderMaterial;
}